summaryrefslogtreecommitdiffstats
path: root/c/src/libchip/ide/ata_internal.h
diff options
context:
space:
mode:
authorThomas Doerfler <Thomas.Doerfler@embedded-brains.de>2010-01-19 09:10:03 +0000
committerThomas Doerfler <Thomas.Doerfler@embedded-brains.de>2010-01-19 09:10:03 +0000
commit5c587596f09da0c52528bcb6a0c3726fcd2cfb07 (patch)
treef3cf6cc9b9cea5f8313e673dc6e8f17b1f928c02 /c/src/libchip/ide/ata_internal.h
parentupdates and new test cases (diff)
downloadrtems-5c587596f09da0c52528bcb6a0c3726fcd2cfb07.tar.bz2
libblock API update
Diffstat (limited to 'c/src/libchip/ide/ata_internal.h')
-rw-r--r--c/src/libchip/ide/ata_internal.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/c/src/libchip/ide/ata_internal.h b/c/src/libchip/ide/ata_internal.h
index 99f98618b7..d0f5ccdeea 100644
--- a/c/src/libchip/ide/ata_internal.h
+++ b/c/src/libchip/ide/ata_internal.h
@@ -210,14 +210,14 @@ typedef struct ata_req_s {
* processing of the ata request is required
*/
rtems_status_code status; /* status of ata request processing */
- int error; /* device error code */
+ int info; /* device info code */
} ata_req_t;
/* call callback provided by block device request if it is defined */
-#define ATA_EXEC_CALLBACK(areq, status, error) \
+#define ATA_EXEC_CALLBACK(areq, status) \
do {\
if (((areq)->breq != NULL) && ((areq)->breq->req_done != NULL)) \
- (areq)->breq->req_done((areq)->breq->done_arg, status, error); \
+ (areq)->breq->req_done((areq)->breq->done_arg, status); \
} while (0)
/* ATA RTEMS driver events types */